@@ -1,8 +1,9 @@
 import json
+import requests
 import string
 from urllib.parse import quote
 
-from django.conf import settings
+from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.middleware.csrf import get_token
 from django.template.loader import render_to_string
 from django.urls import reverse
@@ -10,33 +11,30 @@ from django.utils.crypto import get_random_string
 from django.utils.html import escapejs, mark_safe
 
 from allauth.account.models import EmailAddress
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.app_settings import QUERY_EMAIL
 from allauth.socialaccount.providers.base import (
     AuthAction,
     AuthProcess,
     ProviderAccount,
 )
+from allauth.socialaccount.providers.facebook.constants import (
+    GRAPH_API_URL,
+    GRAPH_API_VERSION,
+    NONCE_LENGTH,
+    NONCE_SESSION_KEY,
+    PROVIDER_ID,
+)
+from allauth.socialaccount.providers.facebook.views import (
+    FacebookOAuth2Adapter,
+)
+from allauth.socialaccount.providers.oauth2.client import OAuth2Error
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 from allauth.utils import import_callable
 
 from .locale import get_default_locale_callable
 
 
-GRAPH_API_VERSION = (
-    getattr(settings, "SOCIALACCOUNT_PROVIDERS", {})
-    .get("facebook", {})
-    .get("VERSION", "v13.0")
-)
-GRAPH_API_URL = (
-    getattr(settings, "SOCIALACCOUNT_PROVIDERS", {})
-    .get("facebook", {})
-    .get("GRAPH_API_URL", "https://graph.facebook.com/{}".format(GRAPH_API_VERSION))
-)
-
-NONCE_SESSION_KEY = "allauth_facebook_nonce"
-NONCE_LENGTH = 32
-
-
 class FacebookAccount(ProviderAccount):
     def get_profile_url(self):
         return self.account.extra_data.get("link")
@@ -57,13 +55,15 @@ class FacebookAccount(ProviderAccount):
 
 
 class FacebookProvider(OAuth2Provider):
-    id = "facebook"
+    id = PROVIDER_ID
     name = "Facebook"
     account_class = FacebookAccount
+    oauth2_adapter_class = FacebookOAuth2Adapter
+    supports_token_authentication = True
 
-    def __init__(self, request):
+    def __init__(self, *args, **kwargs):
         self._locale_callable_cache = None
-        super(FacebookProvider, self).__init__(request)
+        super().__init__(*args, **kwargs)
 
     def get_method(self):
         return self.get_settings().get("METHOD", "oauth2")
@@ -71,7 +71,7 @@ class FacebookProvider(OAuth2Provider):
     def get_login_url(self, request, **kwargs):
         method = kwargs.pop("method", self.get_method())
         if method == "js_sdk":
-            next = "'%s'" % escapejs(kwargs.get("next") or "")
+            next = "'%s'" % escapejs(kwargs.get(REDIRECT_FIELD_NAME) or "")
             process = "'%s'" % escapejs(kwargs.get("process") or AuthProcess.LOGIN)
             action = "'%s'" % escapejs(kwargs.get("action") or AuthAction.AUTHENTICATE)
             scope = "'%s'" % escapejs(kwargs.get("scope", ""))
@@ -121,8 +121,8 @@ class FacebookProvider(OAuth2Provider):
         ]
         return settings.get("FIELDS", default_fields)
 
-    def get_auth_params(self, request, action):
-        ret = super(FacebookProvider, self).get_auth_params(request, action)
+    def get_auth_params_from_request(self, request, action):
+        ret = super().get_auth_params_from_request(request, action)
         if action == AuthAction.REAUTHENTICATE:
             ret["auth_type"] = "reauthenticate"
         elif action == AuthAction.REREQUEST:
@@ -136,8 +136,8 @@ class FacebookProvider(OAuth2Provider):
         return init_params
 
     def get_fb_login_options(self, request):
-        ret = self.get_auth_params(request, "authenticate")
-        ret["scope"] = ",".join(self.get_scope(request))
+        ret = self.get_auth_params_from_request(request, "authenticate")
+        ret["scope"] = ",".join(self.get_scope_from_request(request))
         if ret.get("auth_type") == "reauthenticate":
             ret["auth_nonce"] = self.get_nonce(request, or_create=True)
         return ret
@@ -154,25 +154,17 @@ class FacebookProvider(OAuth2Provider):
         return sdk_url
 
     def media_js(self, request):
-        # NOTE: Avoid loading models at top due to registry boot...
-        from allauth.socialaccount.models import SocialApp
-
-        try:
-            app = self.get_app(request)
-        except SocialApp.DoesNotExist:
-            # It's a problem that Facebook isn't configured; but don't raise
-            # an error. Other providers don't raise errors when they're missing
-            # SocialApps in media_js().
+        if self.get_method() != "js_sdk":
             return ""
 
         def abs_uri(name):
             return request.build_absolute_uri(reverse(name))
 
         fb_data = {
-            "appId": app.client_id,
+            "appId": self.app.client_id,
             "version": GRAPH_API_VERSION,
             "sdkUrl": self.get_sdk_url(request),
-            "initParams": self.get_init_params(request, app),
+            "initParams": self.get_init_params(request, self.app),
             "loginOptions": self.get_fb_login_options(request),
             "loginByTokenUrl": abs_uri("facebook_login_by_token"),
             "cancelUrl": abs_uri("socialaccount_login_cancelled"),
@@ -217,5 +209,17 @@ class FacebookProvider(OAuth2Provider):
             ret.append(EmailAddress(email=email, verified=False, primary=True))
         return ret
 
+    def verify_token(self, request, token):
+        from allauth.socialaccount.providers.facebook import flows
+
+        access_token = token.get("access_token")
+        if not access_token:
+            raise get_adapter().validation_error("invalid_token")
+        try:
+            login = flows.verify_token(request, self, access_token)
+        except (OAuth2Error, requests.RequestException) as e:
+            raise get_adapter().validation_error("invalid_token") from e
+        return login
+
 
 provider_classes = [FacebookProvider]
