@@ -1,5 +1,6 @@
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
+from allauth.socialaccount.providers.slack.views import SlackOAuth2Adapter
 
 
 class SlackAccount(ProviderAccount):
@@ -18,11 +19,17 @@ class SlackProvider(OAuth2Provider):
     id = "slack"
     name = "Slack"
     account_class = SlackAccount
+    oauth2_adapter_class = SlackOAuth2Adapter
 
     def extract_uid(self, data):
+        team_id = data.get("https://slack.com/team_id")
+        user_id = data.get("https://slack.com/user_id")
+        if not (team_id and user_id):
+            team_id = data.get("team").get("id")
+            user_id = data.get("user").get("id")
         return "%s_%s" % (
-            str(data.get("team").get("id")),
-            str(data.get("user").get("id")),
+            str(team_id),
+            str(user_id),
         )
 
     def extract_common_fields(self, data):
