@@ -28,11 +28,10 @@ class TrelloProvider(OAuthProvider):
             name=data.get("name"),
         )
 
-    def get_auth_params(self, request, action):
-        data = super(TrelloProvider, self).get_auth_params(request, action)
+    def get_auth_params_from_request(self, request, action):
+        data = super().get_auth_params_from_request(request, action)
         data["type"] = "web_server"
         data["name"] = self.app.name
-        data["scope"] = self.get_scope(request)
         # define here for how long it will be, this can be configured on the
         # social app
         data["expiration"] = "never"
